// Wrappers for GNOME config functions.

#include <stddef.h>


char *
get_config_string(const char * /*path*/)
{
    return NULL;
}


void
set_config_string(const char * /*path*/, const char * /*value*/)
{
}


void
sync_config()
{
}
